stalker.ext.auth.set_password — Stalker v0.1.1.a9 documentation

### Navigation

- index
- next |
- previous |
- Stalker v0.1.1.a9 documentation »

# stalker.ext.auth.set_password

static `auth.` `set_password`(raw_password)

  Returns an encrypted version of the given password.

  Parameters: | raw_password (string) – The raw password to be encrypted. The raw_password attribute can not be None or empty string.
  Returns: | string

### Navigation

- index
- next |
- previous |
- Stalker v0.1.1.a9 documentation »